@@ -1,6 +1,7 @@
 from aibro.comm import Comm  # noqa
-from aibro.fit import Fit  # noqa
+from aibro.inference import Inference  # noqa
 from aibro.job import Job  # noqa
+from aibro.training import Training  # noqa
 
 # from aibro.model import Model  # noqa
 # from aibro.training_data import Data  # noqa
