@@ -12,6 +12,6 @@ IS_LOCAL = os.environ.get("IS_LOCAL", "false") == "true"
 IS_DEMO = os.environ.get("IS_DEMO", "false") == "true"
 
 # TODO: move this limitation check to aibro server
-INPUT_DATA_SIZE_LIMIT_MB = 1024 * 1.5
+INPUT_DATA_SIZE_LIMIT_MB = 1024 * 4
 
 INF_HOST = os.environ.get("SERVER_HOST", "http://api.aipaca.ai")
