@@ -216,12 +216,14 @@ def _dryrun_helper(
     Test: check if predict.py can return inference result
     """
     err_msg = "Invalid repo structure (checkout https://doc.aipaca.ai for details)."
-    check = _detect(artifacts_path)  # firt, check if the repo structure is our format
+    correct_format = _detect(
+        artifacts_path
+    )  # first, check if the repo structure is our format
     aibro_dir_path = os.path.split(os.path.realpath(__file__))[0]
     inf = os.path.join(aibro_dir_path, "scripts", "infer_command.sh")
     call = os.path.join(aibro_dir_path, "scripts", "call_predict.sh")
     artifacts_path_abspath = os.path.abspath(artifacts_path)
-    if check:  # if it is suitable
+    if correct_format:  # if it is suitable
         try:
             bash = f"bash {inf} {artifacts_path_abspath}"
             subprocess_to_stdout(
@@ -236,11 +238,18 @@ def _dryrun_helper(
                 line_to_stop_streaming="Prediction finished",
             )
         except Exception as e:
-            raise Exception(f"DRYRUN TEST: failed - {str(e)}")
+            e_str = "- " + str(e) if str(e) else str(e)
+            err_msg = f"DRYRUN TEST: failed {e_str}"
+            print_err(err_msg)
+            return err_msg
     else:
-        raise Exception(f"DRYRUN TEST: failed - {err_msg}")
+        err_msg = "- " + str(err_msg)
+        err_msg = f"DRYRUN TEST: failed {str(err_msg)}"
+        return err_msg
 
-    print_highlight("DRYRUN TEST: passed")
+    success_msg = "DRYRUN TEST: passed"
+    print_highlight(success_msg)
+    return success_msg
 
 
 def _create_new_inf_job(data):
@@ -365,16 +374,16 @@ def _deploy_inf_model_setup_helper(
 ):
     try:
         # setup inference
-        spot_client_follow_inf_copy = SpotClient(port=12347)
-        spot_client_follow_inf_copy.set_host(server_public_ip)
-        spot_client_follow_inf_copy.connect_to_socket()
-        resp = spot_client_follow_inf_copy.post_with_byte_data(
+        inf_ins_client = SpotClient(port=12347)
+        inf_ins_client.set_host(server_public_ip)
+        inf_ins_client.connect_to_socket()
+        resp = inf_ins_client.post_with_byte_data(
             f"v1/{user_id}/inf_setup", filepath=zip_path
         )
         if isinstance(resp, Response) and resp.status_code != 200:
             return _terminate_inference_job(job_id, resp.text, [server_public_ip])
         # disconnect everything
-        spot_client_follow_inf_copy.disconnect_socket()
+        inf_ins_client.disconnect_socket()
         # _disconnect_inf_follow_app(job_id, follow_server_thread)
     except Exception as e:
         error = str(e)
